@@ -27,6 +27,7 @@ class SystemInformation: public QObject
     Q_OBJECT
     public:
         explicit SystemInformation(QObject * parent = 0);
+        ~SystemInformation();
 
         QString bugzillaPlatform() const;
         void setBugzillaPlatform(const QString &);
@@ -46,8 +47,14 @@ class SystemInformation: public QObject
         void lsbReleaseFinished();
 
     private:
-        void fetchOSInformation();
-        void runLsbRelease();
+        QString fetchOSBasicInformation() const;
+        QString fetchOSDetailInformation() const;
+        QString fetchOSReleaseInformation() const;
+
+        QString guessBugzillaPlatform(const QString&) const;
+
+        void tryToSetBugzillaPlatform();
+        void tryToSetBugzillaPlatformFromExternalInfo();
 
         QString     m_operatingSystem;
         QString     m_bugzillaOperatingSystem;
